
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.0.post1',
    'branch_nick': '(HEAD',
    'revision_id': '5d87a0b1388729a8fe241f1ec9f2e697ce20dcd4',
    'revno': 9005
}
